import { RowProps } from './Row';
import { default as React } from 'react';
import { SxProps } from '@mui/system/styleFunctionSx';
import { Theme } from '@mui/material';

export interface UniqueIdentifier {
    id: string | number;
}
export interface DraggableRow {
    dragDisabled?: boolean;
}
export interface Column<Data extends UniqueIdentifier & DraggableRow> {
    title?: string;
    field?: keyof Data;
    width?: string;
    headerStyle?: SxProps<Theme>;
    cellStyle?: SxProps<Theme>;
    render?: (data: Data) => React.ReactNode;
    flex?: number;
}
export interface Action<T extends UniqueIdentifier> {
    tooltip: ((data: T) => string) | string;
    icon: (data: T) => React.ReactNode;
    onClick?: (data: T) => Promise<void> | void;
    isLinkToDetails?: boolean;
    href?: (data: T) => string;
    disabled?: (data: T) => boolean;
    needConfirmation?: boolean;
    confirmMessage?: (data: T) => string;
}
export interface TableProps<Data extends UniqueIdentifier & DraggableRow> {
    data: Data[];
    noData?: string;
    columns: Column<Data>[];
    renderRow?: (props: RowProps<Data>) => React.ReactNode;
    details?: (data: Data) => React.ReactNode;
    onClick?: (data: Data) => void;
    actions?: Action<Data>[];
    draggable?: boolean;
    onDragEnd?: (fromId: number | string, toId: number | string, fromIndex: number, toIndex: number) => Promise<void>;
}
export declare const Table: {
    <Data extends UniqueIdentifier & DraggableRow>({ columns, noData, data: sourceData, details, onClick, actions, draggable, onDragEnd, }: TableProps<Data>): import("react/jsx-runtime").JSX.Element;
    displayName: string;
};
